<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://www.itpathsolutions.com/
 * @since      1.0.0
 *
 * @package    Advanced_Images_Gallery_With_Lightbox
 * @subpackage Advanced_Images_Gallery_With_Lightbox/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Advanced_Images_Gallery_With_Lightbox
 * @subpackage Advanced_Images_Gallery_With_Lightbox/includes
 * @author     It Path Solutions <shailm@itpathsolutions.com>
 */
class Advanced_Images_Gallery_With_Lightbox {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Advanced_Images_Gallery_With_Lightbox_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'ADVANCED_IMAGES_GALLERY_WITH_LIGHTBOX_VERSION' ) ) {
			$this->version = ADVANCED_IMAGES_GALLERY_WITH_LIGHTBOX_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'advanced-images-gallery-with-lightbox';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Advanced_Images_Gallery_With_Lightbox_Loader. Orchestrates the hooks of the plugin.
	 * - Advanced_Images_Gallery_With_Lightbox_i18n. Defines internationalization functionality.
	 * - Advanced_Images_Gallery_With_Lightbox_Admin. Defines all hooks for the admin area.
	 * - Advanced_Images_Gallery_With_Lightbox_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-advanced-images-gallery-with-lightbox-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-advanced-images-gallery-with-lightbox-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-advanced-images-gallery-with-lightbox-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-advanced-images-gallery-with-lightbox-public.php';

		$this->loader = new Advanced_Images_Gallery_With_Lightbox_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Advanced_Images_Gallery_With_Lightbox_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Advanced_Images_Gallery_With_Lightbox_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Advanced_Images_Gallery_With_Lightbox_Admin( $this->get_plugin_name(), $this->get_version() );

	
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_action( 'save_post',$plugin_admin,'aigwl_gallery_update_settings',10,2);
		$this->loader->add_filter( 'plugin_action_links_'.$this->plugin_name.'/'.$this->plugin_name.'.php',$plugin_admin,'aigwl_settings_link',10,1 );
		$this->loader->add_action( 'add_meta_boxes', $plugin_admin,'aigwl_metabox');
		$this->loader->add_action( 'init', $plugin_admin,'aigwl_gallery_custom_post_type');
		$this->loader->add_action( 'manage_aigwl_gallery_posts_custom_column' ,$plugin_admin, 'aigwl_new_coulmn', 10, 3 );
		$this->loader->add_filter('manage_aigwl_gallery_posts_columns' ,$plugin_admin, 'set_custom_edit_aigwl_cpt_columns');

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Advanced_Images_Gallery_With_Lightbox_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		$this->loader->add_action( 'init', $plugin_public, 'register_aigwl_gallery_shortcode');
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Advanced_Images_Gallery_With_Lightbox_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

	public function aigwl_get_options() {
		global $post;
		$options = [];
		
		$options['aigwl_display_layout'] = get_post_meta($post->ID,'aigwl_display_layout',true);
	
		$options['aigwl_shortcode_name'] = get_post_meta($post->ID,'aigwl_shortcode_name',true);

		$options['aigwl_display_layout'] = get_post_meta($post->ID,'aigwl_display_layout',true);
		$options['aigwl_image_hover_effect'] = get_post_meta($post->ID,'aigwl_image_hover_effect',true);
		
		$options['aigwl_gallery'] = get_post_meta($post->ID,'aigwl_gallery',true);
		
		return $options;
	}

	public function aigwl_get_all_post_type() {
		$aigwl_post_types	   = get_post_types(array('public' => true,'_builtin' => false),'names','and'); // set arguments to list out the post types
		
		$aigwl_post_types['posts'] = 'post';
		return $aigwl_post_types;
	}

	public function aigwl_display_layout_options() {
		$layout_options = array(
			'1' => 'Grid Gallery',
			'2' => 'Masonary Gallery',
			'3' => 'Diamond Gallery',
			'4' => 'Full Width Gallery',
			'5' => 'Slick Slider',
			'6' => 'Hexagonal Gallery'
		);
		return $layout_options;
	}
	public function aigwl_image_hover_effect_options() {
		$hover_effect_option = array(
			'1' => 'Black Overlay',
			'2' => 'Zoom In Effect',
			'3' => 'Zoom Out Effect',
			'4' => 'No Overlay Effect',
			'5' => 'Grey Scale Effect',
			'6' => 'Wooble Vertical Effect'
		);
		return $hover_effect_option;
	}
}
